@@ -31,7 +31,7 @@ class FeatureUtil():
         self.neg_sample = config['neg_sample']
         self.seq_num = self.config['seq_num']
 
-    def feature_extraction(self, data, predict=False, padding=False, sparse=True):
+    def feature_extraction(self, data, predict=False, padding=False, sparse=True,torch=False):
         feature_id = {
             'role_id': 0,
             'role_id_hash': 1,
@@ -72,6 +72,15 @@ class FeatureUtil():
         user_features_id = [sample + [0] * (self.user_feature_num - len(sample)) for sample in user_features_id]
         # label_week_id = [[int(data[i].split('@')[feature_id['pos_label']].split(':')[1])] * len(sequence_id[i]) for i in range(len(data))]
 
+        if torch:
+            cross_features_index = [[[i, int(y.split(':')[0])] for y in re.split(', |,', sample.split('@')[feature_id['cross_feature']])] for i, sample in enumerate(data)]
+            cross_features_index, cross_features_val = self.cross_features_batch(cross_features_index, cross_features_val)
+            sequence_id = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_id]
+            sequence_time = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_time]
+            sequence_time_gaps = [sequence.pad_sequences(x, maxlen=self.maxlen, padding='post') for x in sequence_time_gaps]
+            return np.array(role_id_hash), np.array(sequence_id), np.array(sequence_time), np.array(sequence_time_gaps), \
+                   np.array(cross_features_index), np.array(cross_features_val), np.array(user_features_id), np.array(cur_time),np.array(pos_label)
+
         if predict == True:
             # assert len(sequence_id) == 1
             cross_features_index = [[[i, int(y.split(':')[0])] for y in re.split(', |,', sample.split('@')[feature_id['cross_feature']])] for i, sample in enumerate(data)]
@@ -105,7 +114,6 @@ class FeatureUtil():
         return index, val
 
     def to_tfrecord(self, csvfile, filename):
-
         writer = tf.python_io.TFRecordWriter(filename)
         data = open(csvfile, 'r', encoding='utf8').read().split('\n')[1:-1]
         role_id_hashs, sequence_ids, sequence_times, sequence_time_gapss, cross_features_indexs, cross_features_vals, user_features_ids, \
@@ -167,7 +175,7 @@ class FeatureUtil():
                 "cross_features_index": tf.io.VarLenFeature(dtype=tf.int64),
                 "cross_features_val": tf.io.VarLenFeature(dtype=tf.float32),
                 "user_features_id": tf.io.VarLenFeature(dtype=tf.int64),
-                "label_week_id": tf.io.VarLenFeature(dtype=tf.int64),
+                # "label_week_id": tf.io.VarLenFeature(dtype=tf.int64),
                 "pos_label": tf.io.VarLenFeature(dtype=tf.int64),
                 "neg_label": tf.io.VarLenFeature(dtype=tf.int64),
                 "mask": tf.io.VarLenFeature(dtype=tf.int64),
