@@ -14,6 +14,11 @@ import datetime
 from dateutil.relativedelta import relativedelta
 
 
+def date_add(date, i):
+    d = datetime.datetime.strptime(date, '%Y-%m-%d')
+    return (d + relativedelta(days=i)).strftime('%Y-%m-%d')
+
+
 def date_sub(date, i):
     d = datetime.datetime.strptime(date, '%Y-%m-%d')
     return (d - relativedelta(days=i)).strftime('%Y-%m-%d')
